'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('@babel/runtime/helpers/extends');
var _objectWithoutProperties = require('@babel/runtime/helpers/objectWithoutProperties');
var React = require('react');
var react = require('@emotion/react');
require('../../constants/breakpoints/index.cjs');
require('../../constants/grid/index.cjs');
require('../../constants/mediaQueries/index.cjs');
require('../../constants/boxShadows/primary.cjs');
require('../../constants/boxShadows/secondary.cjs');
var checkmarkIcon = require('../../icons/icons/checkmarkIcon.cjs');
var chevronIcon = require('../../icons/icons/chevronIcon.cjs');
var errorIcon = require('../../icons/icons/errorIcon.cjs');
var infoIcon = require('../../icons/icons/infoIcon.cjs');
var index$1 = require('../avatar/index.cjs');
var style = require('./style.cjs');
var index = require('../../utils/isDefined/index.cjs');
var hooks = require('./hooks.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var _objectWithoutProperties__default = /*#__PURE__*/_interopDefaultLegacy(_objectWithoutProperties);

var _excluded = ["avatarSrc", "content", "ctaContent", "duration", "onExit", "truncateText", "type"],
    _excluded2 = ["onExit"];
var ANIMATION_DELAY = 500;
var alertIconMapping = {
  success: checkmarkIcon["default"],
  error: errorIcon["default"],
  danger: errorIcon["default"],
  default: infoIcon["default"]
};
/**
 * Alerts should be used to show notifications or messages from (providers, support, or system).
 *
 * They should show page-level success states.
 *
 * We should avoid using alerts to show flow-level success states (i.e. Cancellation successful)
 *
 * Alerts contain some visual marker, an icon `16px` or avatar `32px`
 *
 * Alerts should have a **bolded** portion of the text that helps inform the user what the alert is about.
 * The text should be short and preferably not extend more than 2 lines. Ellipses (...) can be used to truncate past 2 lines via the prop `truncateText`.
 *
 * Alerts can contain a CTA section. These should be reserved for really important actions. These alerts persists until an action is taken.
 *
 * The `<Alert />` component provides only the styling for and enter/exit behavior for alerts.
 * Management of what alerts are showing on the screen must be handled from outside of this component.
 *
 * All alerts are dimissable by clicking on them. However, you can use the `duration` prop to determine if the alert is sticky or dismissed on a timer (in units of seconds).
 */

var Alert = alertProps => {
  var {
    avatarSrc = '',
    content,
    ctaContent = null,
    duration = 3,
    onExit = () => undefined,
    truncateText = false,
    type = 'default'
  } = alertProps,
      rest = _objectWithoutProperties__default["default"](alertProps, _excluded);

  var theme = react.useTheme();
  var [exiting, setExiting] = React.useState(false);
  var [exited, setExited] = React.useState(false);
  var {
    contentText
  } = hooks.useTruncateText(truncateText);
  var timer;

  var alertExitHandler = () => {
    setExiting(true);
    window.clearTimeout(timer);

    var otherProps = _objectWithoutProperties__default["default"](alertProps, _excluded2);

    window.setTimeout(() => {
      setExited(true);
      onExit(otherProps);
    }, ANIMATION_DELAY);
  };
  /**
   * Duration logic effect
   */


  React.useEffect(() => {
    if (duration === 'sticky' || !!ctaContent) {
      return;
    }

    timer = window.setTimeout(alertExitHandler, Number(duration) * 1000 - ANIMATION_DELAY);
    return () => {
      if (index.isDefined(timer)) {
        window.clearTimeout(timer);
      }
    };
  }, []);

  if (exited) {
    return null;
  }

  var Icon = alertIconMapping[type];
  return react.jsx(style["default"].AlertContainer, _extends__default["default"]({
    alertType: type,
    exiting: exiting,
    onClick: alertExitHandler // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), react.jsx(style["default"].MainContainer, null, react.jsx(style["default"].IconContainer, {
    hasAvatar: !!avatarSrc
  }, avatarSrc ? react.jsx(index$1.Avatar, {
    size: "small",
    src: avatarSrc,
    alt: "avatar"
  }) : react.jsx(Icon, {
    fill: theme.COLORS.white
  })), react.jsx(style["default"].ContentContainer, {
    truncateText: truncateText,
    ref: contentText
  }, content)), ctaContent && react.jsx(style["default"].CtaContent, null, react.jsx("div", null, ctaContent), react.jsx(chevronIcon["default"], {
    fill: theme.COLORS.white,
    width: 14,
    height: 14
  })));
};
Alert.Container = style["default"].AlertsContainer;

exports.Alert = Alert;
