import React from 'react';
import Style from './style';
import { ThemeColors } from '../../../../constants';
import type { ButtonTypeWithAction } from '../../types';
export interface RoundButtonProps {
    buttonColor?: ThemeColors;
    /**
     * Determines the button's main style theme
     */
    buttonType?: ButtonTypeWithAction;
    /**
     * Node to be rendered inside the button. Recommended to be the button text
     */
    children?: React.ReactNode;
    disabled?: boolean;
    /**
     * Icon to render in the button. Recommended to be a Radiance icon
     */
    icon: React.ReactNode;
    /**
     * When loading, onClick function execution is disallowed
     */
    isLoading?: boolean;
    loading?: boolean;
    onClick?: () => void;
    /**
     * Color that will override existing text, icon, and loading colors (except when disabled is true)
     */
    textColor?: ThemeColors;
    [key: string]: unknown;
}
interface RoundButton extends React.FC<RoundButtonProps> {
    Container: typeof Style.RoundButtonContainer;
}
/**
 * `<RoundButton />` behaves mostly the same as `<Button />` except that it requires an `icon` prop since that is the main content placed with in the round button. Any children of the component will be rendered immediately below the round button.
 *
 * `<RoundButton.Container>` can be used to wrap `<RoundButton />` components. Since it has some opinions on width and spacing, the max number of buttons you want to wrap is **2**.
 *
 * We should generally try to use the default button color when possible. Only for special cases should we need to use a different button color.
 */
export declare const RoundButton: RoundButton;
declare const _default: RoundButton;
export default _default;
//# sourceMappingURL=index.d.ts.map