import React from 'react';
import Style from './style';
export interface CalloutProps {
    /**
     * Content of the Callout element. It may contain `<strong>` tags
     */
    children: React.ReactNode;
    /**
     * Icon displayed inside the callout right aligned
     */
    icon?: React.ReactNode;
    /**
     * Callback used to display a close (X) icon for closing the callout as well as executing logic upon clicking the close icon
     */
    onClose?: () => void;
    /**
     * Custom prop to draw on preset Callout styles
     */
    type?: 'error' | 'success';
}
interface Callout extends React.FC<CalloutProps> {
    Container: typeof Style.ParentContainer;
}
/**
 * Callouts should be used to provide valuable information or additional context on a page. One of the best examples of a callout is for product recommendations.
 *
 * `Callout` will cover the entirety of the container that holds it. You may optionally wrap it with `Callout.Container` which will set the `max-width` to `327px`.
 *
 * If you use a glyph as callout icon the recommended dimesions are 48x48 pixels (which is the default for Glyphs).
 */
export declare const Callout: Callout;
export {};
//# sourceMappingURL=index.d.ts.map