'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

require('react');
var react = require('@emotion/react');
require('@babel/runtime/helpers/extends');
require('@babel/runtime/helpers/objectWithoutProperties');
require('../../constants/breakpoints/index.cjs');
require('../../constants/grid/index.cjs');
require('../../constants/mediaQueries/index.cjs');
require('../../constants/boxShadows/primary.cjs');
require('../../constants/boxShadows/secondary.cjs');
var chevronIcon = require('../../icons/icons/chevronIcon.cjs');
var style = require('./style.cjs');

var Dropdown = _ref => {
  var {
    borderRadius,
    id,
    onChange,
    onDropdownContainerFocus,
    options,
    textAlign = 'left',
    value,
    ariaLabel
  } = _ref;
  var theme = react.useTheme();
  var touchSupported = ('ontouchstart' in document.documentElement);

  var onSelectChange = event => {
    var {
      target
    } = event;
    var {
      selectedIndex,
      selectedOptions
    } = target;
    var selectedOption = options[selectedIndex];

    if (selectedOptions.length) {
      onChange(selectedOption);
    }
  };

  var handleOnDropdownContainerFocus = event => {
    if (onDropdownContainerFocus) {
      onDropdownContainerFocus(event);
    }
  };

  return react.jsx(style["default"].DropdownContainer, {
    textAlign: textAlign
  }, react.jsx("select", {
    css: style["default"].dropdownInputStyle({
      borderRadius: borderRadius !== null && borderRadius !== void 0 ? borderRadius : theme.BORDER_RADIUS.small,
      shouldBeFullyRounded: true,
      textAlign,
      theme
    }),
    id: id,
    value: value !== null && value !== void 0 ? value : '',
    "aria-label": ariaLabel,
    onChange: onSelectChange,
    onFocus: handleOnDropdownContainerFocus
  }, options.map((option, index) => {
    var _option$value;

    var isDisabled = option.disabled;
    /*
     * We use touchSupported to prevent setting the default value to disabled
     */

    if (option.value === value && touchSupported) {
      isDisabled = false;
    }

    return react.jsx("option", {
      key: (_option$value = option.value) !== null && _option$value !== void 0 ? _option$value : "undefined-".concat(index),
      value: option.value,
      disabled: isDisabled
    }, option.label);
  })), react.jsx(style["default"].IconContainer, null, react.jsx(chevronIcon["default"], {
    width: 15,
    height: 15
  })));
};

exports.Dropdown = Dropdown;
