'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _objectWithoutProperties = require('@babel/runtime/helpers/objectWithoutProperties');
var _extends = require('@babel/runtime/helpers/extends');
var React = require('react');
var ReactDOM = require('react-dom');
var reactTransitionGroup = require('react-transition-group');
var throttle = require('lodash.throttle');
var focus = require('@react-aria/focus');
var dialog = require('@react-aria/dialog');
var index = require('../../constants/portals/index.cjs');
var index$1 = require('../offClickWrapper/index.cjs');
var react = require('@emotion/react');
require('../../constants/breakpoints/index.cjs');
require('../../constants/grid/index.cjs');
require('../../constants/mediaQueries/index.cjs');
require('../../constants/boxShadows/primary.cjs');
require('../../constants/boxShadows/secondary.cjs');
var crossIcon = require('../../icons/icons/crossIcon.cjs');
var style = require('./style.cjs');
var index$2 = require('../../utils/isDefined/index.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _objectWithoutProperties__default = /*#__PURE__*/_interopDefaultLegacy(_objectWithoutProperties);
var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var ReactDOM__default = /*#__PURE__*/_interopDefaultLegacy(ReactDOM);
var throttle__default = /*#__PURE__*/_interopDefaultLegacy(throttle);

var _excluded = ["children", "footerContent", "headerImage", "onClose", "title"];
var MODAL_MOBILE_SCROLLING_ID = 'modal-mobile-scrolling-id';
var MODAL_DESKTOP_SCROLLING_ID = 'modal-desktop-scrolling-id';

var getHtmlNode = () => {
  var _document$querySelect;

  return (_document$querySelect = document.querySelector('html')) !== null && _document$querySelect !== void 0 ? _document$querySelect : document.body;
};

var getDomNode = () => {
  var _document$getElementB;

  return (_document$getElementB = document.getElementById(index.REACT_PORTAL_SECTION_ID)) !== null && _document$getElementB !== void 0 ? _document$getElementB : document.body;
};

var getModalMobileScrollingElement = () => document.getElementById(MODAL_MOBILE_SCROLLING_ID);

var getModalDesktopScrollingElement = () => document.getElementById(MODAL_DESKTOP_SCROLLING_ID);
/**
 * We define a standalone component, ImmersiveModalContent, in order to add
 * `useFocusManager` functionality, which only works as a child of <FocusScope>
 */


var ImmersiveModalContent = _ref => {
  var {
    footerContent,
    headerImage,
    showDesktopHeaderBar,
    showMobileHeaderBar,
    title,
    handleCloseIntent,
    children
  } = _ref;
  var ref = React__default["default"].useRef(null);
  var focusManager = focus.useFocusManager();
  /**
   * Exposes ARIA dialog role to assistive technology, i.e., announces to users with
   * screen readers that they are in a dialog component, thereby making apparent
   * additional accessibility functionality (e.g., exiting dialog with "Esc" key)
   */

  var {
    dialogProps,
    titleProps
  } = dialog.useDialog({
    role: 'dialog'
  }, ref);
  /**
   * It is not typical modal behavior to be able to scroll. Consequently, our
   * keyboard autofocus handling means when users try and scroll in the ImmersiveModal,
   * nothing happens. We make the content of the container tabbable such that when the
   * arrow keys are used (as in normal scroll behavior) we are able to break focus with
   * the close button and allow scrolling of the content
   */

  var onKeyDown = event => {
    switch (event.key) {
      case 'ArrowDown':
        focusManager.focusNext({
          wrap: true
        });
        break;

      case 'ArrowUp':
        focusManager.focusPrevious({
          wrap: true
        });
        break;
    }
  };

  var hasHeaderImage = index$2.isDefined(headerImage);
  return react.jsx(style["default"].MainModalContentContainer, _extends__default["default"]({
    id: MODAL_DESKTOP_SCROLLING_ID,
    hasHeaderImage: hasHeaderImage,
    ref: ref
  }, dialogProps), !showMobileHeaderBar && react.jsx(React__default["default"].Fragment, null, react.jsx(style["default"].DesktopHeaderBar, _extends__default["default"]({}, titleProps, {
    showDesktopHeaderBar: showDesktopHeaderBar
  }), react.jsx("span", null, title)), react.jsx(style["default"].CrossIconButton, {
    onClick: handleCloseIntent,
    showDesktopHeaderBar: showDesktopHeaderBar,
    onKeyDown: onKeyDown,
    "aria-label": "Close modal"
  }, react.jsx(crossIcon["default"], null))), hasHeaderImage && react.jsx(style["default"].HeaderImageContainer, null, headerImage), react.jsx(style["default"].ContentWithFooterContainer, {
    hasHeaderImage: hasHeaderImage,
    tabIndex: 0
  }, react.jsx("div", null, index$2.isDefined(title) && react.jsx(style["default"].ModalTitle, null, title), react.jsx("section", null, children)), index$2.isDefined(footerContent) && react.jsx(style["default"].ModalFooter, null, footerContent)));
};
/**
 * It is used to provide a layer on top of a page when we need to present more content and actions to patients.
 *
 * It should not be used as a step to add friction / confirm an action, use `Dialog Modal` instead.
 *
 * They are closable if clicked outside of container.
 *
 * Immersive modals always include the close button.
 *
 * Modals can contain a header image that is 240px tall (264px on desktop). Images should not contain rounded corners.
 *
 * `ImmersiveModal.Paragraph` subcomponent may be used to add some margin to the paragraphs inside the modal body.
 */


var ImmersiveModal = _ref2 => {
  var {
    children,
    footerContent = null,
    headerImage = null,
    onClose,
    title = ''
  } = _ref2,
      rest = _objectWithoutProperties__default["default"](_ref2, _excluded);

  var [isClosing, setIsClosing] = React.useState(false);
  var [showMobileHeaderBar, setShowMobileHeaderBar] = React.useState(false);
  var [showDesktopHeaderBar, setShowDesktopHeaderBar] = React.useState(false);
  var htmlNode = React.useRef(getHtmlNode());
  var domNode = React.useRef(getDomNode());
  var modalMobileScrollingElement = React.useRef(getModalMobileScrollingElement());
  var modalDesktopScrollingElement = React.useRef(getModalDesktopScrollingElement());
  var handleScroll = throttle__default["default"](() => {
    if (modalMobileScrollingElement.current) {
      var shouldShowMobileHeaderBar = modalMobileScrollingElement.current.scrollTop > 32;
      setShowMobileHeaderBar(shouldShowMobileHeaderBar);
    }

    if (modalDesktopScrollingElement.current) {
      var shouldShowDesktopHeaderBar = modalDesktopScrollingElement.current.scrollTop > 32;
      setShowDesktopHeaderBar(shouldShowDesktopHeaderBar);
    }
  }, 100);

  var handleCloseIntent = () => {
    if (isClosing) {
      return;
    }

    setIsClosing(true);
    setShowMobileHeaderBar(false);
    setTimeout(onClose, 450);
  };

  React.useEffect(() => {
    htmlNode.current = getHtmlNode();
    domNode.current = getDomNode();
    modalMobileScrollingElement.current = getModalMobileScrollingElement();
    modalDesktopScrollingElement.current = getModalDesktopScrollingElement();
    var htmlNodeInstance = htmlNode.current;
    var modalMobileScrollingElementInstance = modalMobileScrollingElement.current;
    var modalDesktopScrollingElementInstance = modalDesktopScrollingElement.current;
    htmlNodeInstance.classList.add('no-scroll');

    if (modalMobileScrollingElementInstance && modalDesktopScrollingElementInstance) {
      modalMobileScrollingElementInstance.addEventListener('scroll', handleScroll);
      modalDesktopScrollingElementInstance.addEventListener('scroll', handleScroll);
    }

    return () => {
      htmlNodeInstance.classList.remove('no-scroll');

      if (modalMobileScrollingElementInstance && modalDesktopScrollingElementInstance) {
        modalMobileScrollingElementInstance.removeEventListener('scroll', handleScroll);
        modalDesktopScrollingElementInstance.removeEventListener('scroll', handleScroll);
      }
    };
  }, []);
  return /*#__PURE__*/ReactDOM__default["default"].createPortal(react.jsx(reactTransitionGroup.Transition, {
    timeout: {
      appear: 0,
      enter: 0,
      exit: 350
    },
    in: !isClosing,
    unmountOnExit: true,
    appear: true
  }, transitionState => react.jsx(React__default["default"].Fragment, null, react.jsx(style["default"].MobileHeaderBar, {
    showMobileHeaderBar: showMobileHeaderBar
  }, title, react.jsx(style["default"].CrossIconButton, {
    onClick: handleCloseIntent,
    "aria-label": "Close modal"
  }, react.jsx(crossIcon["default"], null))), react.jsx(style["default"].Overlay, _extends__default["default"]({
    className: transitionState
  }, rest), react.jsx(style["default"].ModalContainer, {
    className: transitionState,
    id: MODAL_MOBILE_SCROLLING_ID
  }, react.jsx(index$1.OffClickWrapper, {
    onOffClick: handleCloseIntent,
    className: "modal-offclick-wrapper"
  }, react.jsx(style["default"].MobileTopOverlay, {
    onClick: handleCloseIntent
  }), react.jsx(focus.FocusScope, {
    contain: true,
    restoreFocus: true,
    autoFocus: true
  }, react.jsx(ImmersiveModalContent, {
    footerContent: footerContent,
    headerImage: headerImage,
    showDesktopHeaderBar: showDesktopHeaderBar,
    showMobileHeaderBar: showMobileHeaderBar,
    title: title,
    handleCloseIntent: handleCloseIntent
  }, children))))))), domNode.current);
};
ImmersiveModal.Paragraph = style["default"].Paragraph;

exports.ImmersiveModal = ImmersiveModal;
