'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('@babel/runtime/helpers/extends');
var _objectWithoutProperties = require('@babel/runtime/helpers/objectWithoutProperties');
require('react');
var style = require('./style.cjs');
var react = require('@emotion/react');
require('../../constants/breakpoints/index.cjs');
require('../../constants/grid/index.cjs');
require('../../constants/mediaQueries/index.cjs');
require('../../constants/boxShadows/primary.cjs');
require('../../constants/boxShadows/secondary.cjs');
var checkmarkIcon = require('../../icons/icons/checkmarkIcon.cjs');
var index = require('../../utils/isDefined/index.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var _objectWithoutProperties__default = /*#__PURE__*/_interopDefaultLegacy(_objectWithoutProperties);

var _excluded = ["borderRadius", "buttonType", "icon", "onClick", "optionType", "selected", "subtext", "text", "image", "textContainerHeight", "alt"],
    _excluded2 = ["borderRadius", "icon", "optionType", "subtext", "text", "image"];
var DEFAULT_BORDER_RADIUS = 'small';
var OptionButtonIcon = _ref => {
  var {
    buttonType = 'primary',
    icon,
    optionType,
    selected = false,
    withImageBackground = false
  } = _ref;

  if (index.isDefined(icon) && icon !== false) {
    return react.jsx(style["default"].IconWrapper, {
      selected: selected,
      optionType: optionType,
      buttonType: buttonType,
      withImageBackground: withImageBackground
    }, selected ? react.jsx(checkmarkIcon["default"], null) : icon);
  }

  return react.jsx(style["default"].CheckmarkWrapper, {
    selected: selected,
    optionType: optionType,
    buttonType: buttonType,
    withImageBackground: withImageBackground
  }, react.jsx(checkmarkIcon["default"], null));
};

var OptionButtonContent = _ref2 => {
  var {
    buttonType = 'primary',
    icon,
    optionType,
    selected = false,
    subtext,
    text,
    image = '',
    borderRadius = DEFAULT_BORDER_RADIUS,
    textContainerHeight,
    alt = ''
  } = _ref2;
  return react.jsx(style["default"].FlexContainer, {
    containsImage: !!image
  }, image ? react.jsx(style["default"].ImageContainer, {
    borderRadius: borderRadius
  }, react.jsx(OptionButtonIcon, {
    selected: selected,
    optionType: optionType,
    buttonType: buttonType,
    icon: icon,
    withImageBackground: true
  }), react.jsx(style["default"].Image, {
    src: image,
    borderRadius: borderRadius,
    alt: alt
  })) : react.jsx(OptionButtonIcon, {
    selected: selected,
    optionType: optionType,
    buttonType: buttonType,
    icon: icon
  }), react.jsx(style["default"].TextContainer, {
    containsImage: !!image,
    height: textContainerHeight
  }, react.jsx(style["default"].Text, {
    bold: !!image
  }, text), index.isDefined(subtext) && react.jsx(style["default"].SubText, null, subtext)));
};
/**
 * The `OptionButton` is used within a focused flow (such as the signup page)
 * to provide more context and attention to each selection option.
 *
 * There is also an OptionButton.Container sub-component to be used when we
 * want to use the OptionButton as a purely presentational component rather
 * than a functional button associated with form inputs
 */


var OptionButton = _ref3 => {
  var {
    borderRadius = DEFAULT_BORDER_RADIUS,
    buttonType,
    icon,
    onClick,
    optionType,
    selected,
    subtext,
    text,
    image = '',
    textContainerHeight,
    alt = ''
  } = _ref3,
      rest = _objectWithoutProperties__default["default"](_ref3, _excluded);

  return react.jsx(style["default"].ClickableContainer, _extends__default["default"]({
    borderRadius: borderRadius,
    onClick: onClick,
    type: "button",
    role: optionType,
    "aria-checked": selected,
    containerType: "clickable",
    containsImage: !!image // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), react.jsx(OptionButtonContent, {
    buttonType: buttonType,
    icon: icon,
    optionType: optionType,
    selected: selected,
    subtext: subtext,
    text: text,
    image: image,
    borderRadius: borderRadius,
    textContainerHeight: textContainerHeight,
    alt: alt
  }));
};
/**
 * A presentational component to match the display of an OptionButton with an icon
 */

var OptionButtonNotClickable = _ref4 => {
  var {
    borderRadius = DEFAULT_BORDER_RADIUS,
    icon,
    optionType,
    subtext,
    text,
    image = ''
  } = _ref4,
      rest = _objectWithoutProperties__default["default"](_ref4, _excluded2);

  return react.jsx(style["default"].DisplayContainer, _extends__default["default"]({
    borderRadius: borderRadius,
    containerType: "none" // eslint-disable-next-line react/jsx-props-no-spreading

  }, rest), react.jsx(OptionButtonContent // The buttonType does not matter for this component
  , {
    buttonType: "primary",
    icon: icon,
    optionType: optionType,
    selected: false,
    subtext: subtext,
    text: text,
    image: image
  }));
};
/**
 * Similar OptionButton styling without click elements
 */

OptionButton.NotClickable = OptionButtonNotClickable;

exports.OptionButton = OptionButton;
exports.OptionButtonIcon = OptionButtonIcon;
exports.OptionButtonNotClickable = OptionButtonNotClickable;
