/**
 * Returns a ref and a function for sending focus to the ref's DOM element.
 * Useful for moving keyboard focus after an event.
 * @example
 * const { initialFocus, resetFocus } = useResetFocus();
 * return (
 *  <React.Fragment>
 *    <button ref={initialFocus}>First Button</button>
 *    <button onClick={() => resetFocus() }>Click Here to send focus to the First Button!</button>
 *  </React.Fragment>
 * );
 *
 */
declare const useResetFocus: <T extends HTMLElement>() => {
    initialFocus: import("react").RefObject<T>;
    resetFocus: () => void;
};
export default useResetFocus;
//# sourceMappingURL=useResetFocus.d.ts.map